Package: biodosetools
Title: 'shiny' Application for Biological Dosimetry
Version: 3.7.2
Authors@R: 
    c(person(given = "Alfredo",
           family = "Hernández",
           role = c("aut"),
           email = "aldomann.designs@gmail.com",
           comment = c(ORCID = "0000-0002-2660-4545")),
      person(given = "Anna",
           family = "Frances-Abellan",
           role = c("aut", "cre"),
           email = "anna.frances@uab.cat",
           comment = c(ORCID = "0000-0003-4738-1712")),
      person(given = "David",
           family = "Endesfelder",
           role = c("aut"),
           email = "dendesfelder@bfs.de"),
      person(given = "Pere",
           family = "Puig",
           role = c("aut"),
           email = "ppuig@mat.uab.cat",
           comment = c(ORCID = "0000-0002-6607-9642")))
Description: A tool to perform all different statistical tests and calculations
    needed by Biological dosimetry Laboratories. Detailed documentation is
    available in <https://biodosetools-team.github.io/documentation/>.
License: GPL-3
URL: https://biodosetools-team.github.io/biodosetools/,
        https://github.com/biodosetools-team/biodosetools/
BugReports: https://github.com/biodosetools-team/biodosetools/issues/
Depends: R (>= 3.5.0), shiny, golem
Imports: bsplus, dplyr (>= 1.0.0), ggplot2, magrittr, maxLik, mixtools,
        msm, pdftools, rhandsontable, rlang (>= 0.4.0), readr,
        shinydashboard, shinyWidgets (>= 0.5.0), tidyr (>= 1.0.0),
        config, cli, openxlsx, MASS, gridExtra, rmarkdown
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.1
Suggests: testthat (>= 3.0.0), covr, knitr, kableExtra, markdown,
        pander, tinytex, xtable
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-12-16 14:39:03 UTC; anna_
Author: Alfredo Hernández [aut] (ORCID:
    <https://orcid.org/0000-0002-2660-4545>),
  Anna Frances-Abellan [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4738-1712>),
  David Endesfelder [aut],
  Pere Puig [aut] (ORCID: <https://orcid.org/0000-0002-6607-9642>)
Maintainer: Anna Frances-Abellan <anna.frances@uab.cat>
Repository: CRAN
Date/Publication: 2025-12-16 15:10:08 UTC
Built: R 4.6.0; ; 2026-04-26 16:39:46 UTC; unix
