#### Report

The report contains:

- Original count data used
- Results of the dose-effect fitting
- Summary statistics
- Irradiation conditions
- Dose-effect plot

The report can be downloaded in `.PDF` and `.DOCX`.

