The project is initially developed by [RENEB](https://www.reneb.net/) association, as a collaboration between Universitat Autònoma de Barcelona ([UAB](https://www.uab.cat/)), Bundesamt für Strahlenschutz ([BfS](https://www.bfs.de/EN/home/home_node.html)), Durham University ([DU](https://www.dur.ac.uk/)), Institut de Radioprotection et de Sûreté Nucléaire ([IRSN](https://www.irsn.fr/EN/Pages/Home.aspx)), Universidad de la Rioja ([UdR](https://www.unirioja.es/)), and UK Health Security Agency ([UKHSA](https://www.gov.uk/government/organisations/uk-health-security-agency)).

### Principal contributors

| Name                                                                                    | Institution | Role                                   |
|-----------------------------------------------------------------------------------------|:-----------:|----------------------------------------|
| [Alfredo Hernández](https://aldomann.com)                                               | UAB         | Statistical programmer and main author |
| [Joan Francesc Barquinero](https://orcid.org/0000-0003-0084-5268)                       | UAB         | Biologist                              |
| [David Endesfelder](https://www.researchgate.net/profile/David-Endesfelder)             | BfS         | Mathematician                          |
| [Pedro Puig](https://orcid.org/0000-0002-6607-9642)                                     | UAB         | Mathematician                          |
| [Leonardo Barrios](https://orcid.org/0000-0002-6151-8503)                               | UAB         | Biologist                              |
| [Jochen Einbeck](https://orcid.org/0000-0002-9457-2020)                                 | DU          | Statistician                           |
| [Mohamed Amine Benadjaoud](https://www.researchgate.net/profile/Mohamed-Benadjaoud-2)   | IRSN        | Biostatistician                        |
| [Elizabeth Ainsbury](https://www.ukhsa-protectionservices.org.uk/cds/team/liz_ainsbury) | UKHSA       | Physicist                              |

### Contributors

| Name                                                                                                      | Institution | Role          |
|-----------------------------------------------------------------------------------------------------------|:-----------:|---------------|
| [Ulrike Kulka](https://orcid.org/0000-0002-7734-3162)                                                     | BfS         | Biologist     |
| [Eric Grègoire](https://www.researchgate.net/profile/Eric-Gregoire)                                       | IRSN        | Biologist     |
| [Manuel Higueras](https://orcid.org/0000-0001-5530-1714)                                                  | UdR         | Mathematician |
| [Gaëtan Gruel](https://www.researchgate.net/profile/Gruel-Gaetan)                                         | IRSN        | Biologist     |
| [Ursula Oestreicher](https://www.researchgate.net/scientific-contributions/Ursula-Oestreicher-2121336457) | BfS         | Biologist     |
