#### Data format

The following parameters need to be input:

- Fitting formula.
- Coefficients.
- Standard error of the coefficients (optional).
- Variance-covariance matrix (optional).

To update the tables accordingly to the selected fitting formula, it's necessary to click on <button class="btn btn-default action-button options-button shiny-bound-input small-action-button"  type="button">Generate table</button>.
