#### Fitting formula

The objective of curve fitting is to determine those values of the coefficients $C$, $\alpha$ and $\beta$ which best fit the data points.

- For low-LET radiation types there is very strong evidence that the yields of chromosome aberrations or micronuclei ($\lambda$) are related to dose ($D$) by the linear quadratic equation $\lambda = C + \alpha D + \beta D^{2}$. 

- For high-LET-radiation, the $\alpha$ term becomes large and eventually the $\beta$ term becomes biologically less relevant and also statistically ‘masked’ and the dose response fits better to a linear equation $\lambda = C + \alpha D$.

The user should check which model fits better with its data. However, because at 0 Gy a certain amount of dicentrics exists (1--2 per thousand cells) it is suggested to fit the data using the intercept value $C$.
