</br>
At the end, click on the <button class="btn btn-default action-button inputs-button shiny-bound-input small-action-button" type="button">Calculate factor</button> to calculate genomic conversion factor, or fraction of genome hybridized, $f = F_{p} / F_{g}$, where
- $F_{p}$ is the observed yield.
- $F_{g}$ is the full genome yield.

#### M-Fish

If you select M-Fish as the color scheme, the application assumes each chromosome has a single individual observed color.
