#### Data

The results can be downloaded in their respective boxes in `.xlsx`, `.csv` or `.tex`

#### Report

The report contains:

- Summary table.
- Z-Score table.
- Additional comments.
- All graphical resources.

The report can be downloaded in `.PDF`.
