#### Data

The results can be downloaded in `.rds` and `.xlsx`.

#### Report

The report contains:

- Case description
- Data input:
    - Dose-effect curve used
    - Original case data used
- Results of the dose estimation
- Dose estimation plot
- Additional comments

The report can be downloaded in `.PDF` and `.DOCX`.
