Protraction or fractionation of the exposure may also produce a lower chromosome aberration yield than if the same dose is received acutely. For high LET radiation, where the dose-response relationship is close to linear, no dose rate or fractionation effect would be expected. For low LET radiation, however, the effect of dose protraction is to reduce the dose squared coefficient, $\beta$, in the yield equation.

A time dependent factor known as the $G$ function enables modification of the dose squared coefficient and thus allow for the effects of dose protraction:
$$ \lambda = C + \alpha D + \beta G(x) D^{2}, $$
$$G(x) = \frac{2}{x^{2}} \left(x - 1 - e^{-x} \right), \quad x = \frac{t}{t_{0}}$$

where $t$ is the time over which the irradiation occurred, and  $t_{0}$ is the mean lifetime of the breaks, which has been shown to be on the order of ~2 hours.

<br>
If "Highly protracted" is selected, $G(x)$ is effectively zero, reducing the yield equation to linear.
