The size of the body irradiated may be derived from $f$ after a correction for the effects of interphase death and mitotic delay.

This correction needs to indicate a $D_0$ value from the literature, between $2.7$ and $3.5$, or a gamma coefficient obtained from own experimental data.
