A P-value (and summary statistics) is calculated based on the null-hypothesis that the counts of the case suspected of exposure to ionizing radiation, and the control data are equal. A two-sided Poisson test based on the R function $poisson.test()$ is calculated. A significant P-value suggests that the case was exposed to a dose $D>0$ Gy and the calculation of the dose shall be performed if an appropriate calibration curve is available. The inputs are the number of dicentrics and the number of cells counted for the case and the control.
