Please provide the list of chromosomes used and of colors visualized on the fluorescence microscope.

For example, if you paint

- \#1 with FITC
- \#4 with Cy3
- \#12 with FITC and Cy3

then you should select three different colors, i.e., Red, Green, and Yellow.

Click on <button class="btn btn-default action-button options-button shiny-bound-input small-action-button"  type="button">Generate table</button> to match each chromosome to its observed color, as seen below:

