The routine tests if cells were irradiated at two different doses. 

- When $x_2$ is equal to $0$ it means that exposure was partial and the routine estimates a single partial-body dose. 
- When $x_1$ and $x2$ are diffrerent from $0$, the routine estimates two doses.
