If the $u$-value is overdispersed, $u > 1.96$, it should be indicative of either
- A non-homogeneous exposure to low-LET radiation.
- An exposure to a high-LET radiation.

If it is suspected an exposure to low-LET radiation, partial or heterogeneous dose estimation should be applied.

Heterogeneous dose estimation is not available for multiple cases.
