#### Confounders

You may also choose from a list of confounders from Sigurdson (2008) to obtain the translocation frequency to be substracted from the observed yield, $X_{c}$.

Likewise, a value for the translocation frequency per cell, $TF$, can be provided manually.

Note that $X_{c} = TF \cdot N \cdot f$, where

- $N$ is the total number of cells.
- $f$ is the genomic conversion factor.
