
#### Deviation from reference

Regarding deviation from reference method, it is the difference between the estimated dose (or the frequency of the aberration) $x_i$, and the reference value $x_{\text{ref}}$:
  $$
  dev= x_i- x_{\text{ref}}
  $$
    
