<br>

<p align="center">
  <img src="www/home.svg" alt="drawing" style="max-width: 500px; width: 60%;"/>
</p>

<br>

<p style="padding-left: 10%; padding-right: 10%;">
  Biodose Tools is an open source project that aims to be a tool to perform all different tests and calculations needed by biological dosimetry laboratories. The app is developed using the <a href="https://www.r-project.org/about.html">R</a> programming language and <a href="https://shiny.rstudio.com/">Shiny</a> as a framework to offer an online, easy-to-use solution. Although the intention is to provide the application as a website, all R routines are available as an R package, which can be downloaded for improvement or personal use.
</p>

<p style="padding-left: 10%; padding-right: 10%;">
  We also aim to clarify and explain the tests used and to propose those considered most appropriate. Each laboratory in its routine work should choose the most suitable method, but the project aims to reach a consensus that will help us in case of mutual assistance or intercomparisons.
</p>

<p style="padding-left: 10%; padding-right: 10%;">
  The project is initially developed by <a href="https://www.reneb.net/">RENEB</a> association, but contributions are always welcome.
</p>

<div style="height: 10px;">
  <br>
</div>
