#### Available methods for dicentrics

**Whole-body estimation**
- Merkle's method (83%-83%).
- Merkle's method (95%-95%).
- Delta method (95%).

**Partial-body estimation**
- Dolphin (95%), based on the Delta method.

**Heterogeneous estimation**
- Merkle's method (83%-83%).
- Merkle's method (95%-95%).
- Delta method (95%).
